@@ -275,7 +275,6 @@ App::handleCliArgs(const QString &cwd)
         for( int i = 0; i < m_args->positionalArguments().count() ; i++ )
         {
             QUrl url( QUrl::fromUserInput( m_args->positionalArguments().at( i ), QString(), QUrl::AssumeLocalFile ) );
-            //TODO:PORTME
             if( Podcasts::PodcastProvider::couldBeFeed( url.url() ) )
             {
                 QUrl feedUrl = Podcasts::PodcastProvider::toFeedUrl( url.url() );
@@ -398,7 +397,7 @@ void App::applySettings()
     else if( !AmarokConfig::showTrayIcon() && m_tray )
     {
         delete m_tray;
-        m_tray = 0;
+        m_tray = nullptr;
     }
 
     Amarok::OSD::instance()->applySettings();
@@ -423,7 +422,7 @@ void App::applySettingsFirstTime()
     else if( !AmarokConfig::showTrayIcon() && m_tray )
     {
         delete m_tray;
-        m_tray = 0;
+        m_tray = nullptr;
     }
 
     if( AmarokConfig::enableScriptConsole() && !m_scriptConsole )
@@ -524,7 +523,7 @@ App::continueInit()
         handleFirstRun();
     }
 
-    if( AmarokConfig::resumePlayback() && restoreSession && m_args->isSet( "stop" ) ) {
+    if( AmarokConfig::resumePlayback() && restoreSession && !m_args->isSet( "stop" ) ) {
         //restore session as long as the user didn't specify media to play etc.
         //do this after applySettings() so OSD displays correctly
         The::engineController()->restoreSession();
