@@ -40,7 +40,7 @@
  *
  *  This must match the desktop files.
  */
-const int Plugins::PluginManager::s_pluginFrameworkVersion = 74;
+const int Plugins::PluginManager::s_pluginFrameworkVersion = 75;
 Plugins::PluginManager* Plugins::PluginManager::s_instance = nullptr;
 
 Plugins::PluginManager*
@@ -141,7 +141,7 @@ Plugins::PluginManager::checkPluginEnabledStates()
     {
         if( qobject_cast<QGuiApplication*>( qApp ) )
         {
-            KMessageBox::error( 0, i18n( "Amarok could not find any plugins. This indicates an installation problem." ) );
+            KMessageBox::error( nullptr, i18n( "Amarok could not find any plugins. This indicates an installation problem." ) );
         }
         else
         {
