@@ -15,47 +15,48 @@
  ****************************************************************************************/
  
 #include "BrowserBreadcrumbItem.h"
+
+#include "browsers/BrowserCategoryList.h"
+#include "browsers/filebrowser/FileBrowser.h"
+#include "core/support/Debug.h"
 #include "widgets/BreadcrumbItemButton.h"
 
-#include "BrowserCategoryList.h"
-#include "core/support/Debug.h"
-
-#include <KIcon>
-#include <KLocale>
-
 #include <QDir>
+#include <QHBoxLayout>
+#include <QIcon>
 #include <QMenu>
 
-BrowserBreadcrumbItem::BrowserBreadcrumbItem( BrowserCategory * category )
-    : KHBox( 0 )
-    , m_category( category )
-    , m_menuButton( 0 )
+#include <KLocalizedString>
+
+
+BrowserBreadcrumbItem::BrowserBreadcrumbItem( BrowserCategory *category, QWidget *parent )
+    : BoxWidget( false, parent )
+    , m_menuButton( nullptr )
 {
     //figure out if we want to add a menu to this item. A menu allows you to select
     //any of the _sibling_ items. (yes, I know, this is different from how Dolphin
     //does it, but I find the Dolphin way amazingly unintuitive and I always get it
     //wrong when using it...)
-
     BrowserCategoryList * parentList = category->parentList();
-    if ( parentList )
+    if( parentList )
     {
         m_menuButton = new BreadcrumbItemMenuButton( this );
-        QMenu *menu = new QMenu( 0 );
-        
+        QMenu *menu = new QMenu( this ); //see QMenu docs: it's still a top-level widget.
+                                         //parent is only for memory management.
         QMap<QString,BrowserCategory *> siblingMap = parentList->categories();
 
-        QStringList siblingNames = siblingMap.keys();
+        const QStringList siblingNames = siblingMap.keys();
 
         foreach( const QString &siblingName, siblingNames )
         {
             //no point in adding ourselves to this menu
-            if ( siblingName == m_category->name() )
+            if ( siblingName == category->name() )
                 continue;
-            
+
             BrowserCategory *siblingCategory = siblingMap.value( siblingName );
-            
+
             QAction *action = menu->addAction( siblingCategory->icon(), siblingCategory->prettyName() );
-            connect( action, SIGNAL( triggered() ), siblingMap.value( siblingName ), SLOT( activate() ) );
+            connect( action, &QAction::triggered, siblingMap.value( siblingName ), &BrowserCategory::activate );
         }
 
         m_menuButton->setMenu( menu );
@@ -67,80 +68,77 @@ BrowserBreadcrumbItem::BrowserBreadcrumbItem( BrowserCategory * category )
     {
         // root item
         m_mainButton->setToolTip( i18n( "Media Sources Home" ) );
-        m_mainButton->setIcon( KIcon( "user-home" ) );
+        m_mainButton->setIcon( QIcon::fromTheme( QStringLiteral("user-home") ) );
     }
 
-    connect( m_mainButton, SIGNAL( sizePolicyChanged() ), this, SLOT( updateSizePolicy() ) );
+    connect( m_mainButton, &BreadcrumbItemButton::sizePolicyChanged, this, &BrowserBreadcrumbItem::updateSizePolicy );
 
-    //if this is a list, make cliking on this item cause us
+    //if this is a list, make clicking on this item cause us
     //to navigate to its home.
     BrowserCategoryList *list = qobject_cast<BrowserCategoryList*>( category );
     if ( list )
     {
-        connect( m_mainButton, SIGNAL( clicked( bool ) ), list, SLOT( home() ) );
+        connect( m_mainButton, &QAbstractButton::clicked, list, &BrowserCategoryList::home );
     }
     else  
     {
-        connect( m_mainButton, SIGNAL( clicked( bool ) ), category, SLOT( reActivate() ) );
+        connect( m_mainButton, &QAbstractButton::clicked, category, &BrowserCategory::reActivate );
     }
 
     adjustSize();
     m_nominalWidth = width();
-    
+
     hide();
 
     updateSizePolicy();
 }
 
-BrowserBreadcrumbItem::BrowserBreadcrumbItem( const QString &name, const QStringList &childItems, const QString &callback, BrowserCategory * handler )
-    : KHBox( 0 )
-    , m_category( 0 )
-    , m_menuButton( 0 )
+BrowserBreadcrumbItem::BrowserBreadcrumbItem( const QString &name, const QString &callback,
+        const BreadcrumbSiblingList &childItems, FileBrowser *handler, QWidget *parent )
+    : BoxWidget( false, parent )
+    , m_menuButton( nullptr )
     , m_callback( callback )
 {
-
     if ( !childItems.isEmpty() )
     {
         m_menuButton = new BreadcrumbItemMenuButton( this );
-        QMenu *menu = new QMenu( 0 );
+        QMenu *menu = new QMenu( this );
 
-        foreach( const QString &siblingName, childItems )
+        int i = 0;
+        foreach( const BreadcrumbSibling &sibling, childItems )
         {
-            QAction *action = menu->addAction( KIcon("folder-amarok"), siblingName );
-            action->setProperty( "directory", siblingName );
+            QString visibleName = sibling.name;
+            visibleName.replace( '&', QLatin1String("&&") ); // prevent bug 244817
+            QAction *action = menu->addAction( sibling.icon, visibleName );
+            action->setProperty( "callback", sibling.callback );
 
             // the current action should be bolded
-            if( siblingName == name )
+            if( sibling.name == name )
             {
                 QFont font = action->font();
                 font.setBold( true );
                 action->setFont( font );
             }
-            connect( action, SIGNAL( triggered() ), this, SLOT( activateSibling() ) );
+            connect( action, &QAction::triggered, this, &BrowserBreadcrumbItem::activateSibling );
+            i++;
         }
         m_menuButton->setMenu( menu );
     }
 
     m_mainButton = new BreadcrumbItemButton( name, this );
-    
-    connect( m_mainButton, SIGNAL( sizePolicyChanged() ), this, SLOT( updateSizePolicy() ) );
-    connect( m_mainButton, SIGNAL( clicked( bool ) ), this, SLOT( activate() ) );
-    connect( this, SIGNAL( activated( const QString & ) ), handler, SLOT( addItemActivated( const QString & ) ) );
+    connect( m_mainButton, &BreadcrumbItemButton::sizePolicyChanged, this, &BrowserBreadcrumbItem::updateSizePolicy );
+    connect( m_mainButton, &QAbstractButton::clicked, this, &BrowserBreadcrumbItem::activate );
+    connect( this, &BrowserBreadcrumbItem::activated, handler, &FileBrowser::addItemActivated );
 
     adjustSize();
     m_nominalWidth = width();
-    
-    hide();
 
+    hide();
     updateSizePolicy(); 
 }
 
-
-
 BrowserBreadcrumbItem::~BrowserBreadcrumbItem()
 {
-    if( m_menuButton )
-        delete m_menuButton->menu();
 }
 
 void
@@ -161,27 +159,17 @@ void BrowserBreadcrumbItem::updateSizePolicy()
 
 void BrowserBreadcrumbItem::activate()
 {
-    emit activated( m_callback );
+    Q_EMIT activated( m_callback );
 }
 
 void BrowserBreadcrumbItem::activateSibling()
 {
     QAction *action = qobject_cast<QAction *>( sender() );
-
     if( action )
-    {
-        QDir dir( m_callback );
-        dir.cdUp();
-
-        QString siblingCallback = dir.path() + QDir::separator() + action->property( "directory" ).toString();
-
-        emit activated( siblingCallback );
-    }
+        Q_EMIT activated( action->property( "callback" ).toString() );
 }
 
 int BrowserBreadcrumbItem::nominalWidth() const
 {
     return m_nominalWidth;
 }
-
-#include "BrowserBreadcrumbItem.moc"
