@@ -24,7 +24,7 @@
 #include "core/support/Debug.h"
 #include "SvgHandler.h"
 
-#include <KIcon>
+#include <QIcon>
 
 #include <QAbstractListModel>
 
@@ -45,11 +45,11 @@ namespace The
     }
 }
 
-PlaylistBrowserNS::UserModel *PlaylistBrowserNS::UserModel::s_instance = 0;
+PlaylistBrowserNS::UserModel *PlaylistBrowserNS::UserModel::s_instance = nullptr;
 
 PlaylistBrowserNS::UserModel *PlaylistBrowserNS::UserModel::instance()
 {
-    if( s_instance == 0 )
+    if( s_instance == nullptr )
         s_instance = new UserModel();
 
     return s_instance;
@@ -61,7 +61,7 @@ PlaylistBrowserNS::UserModel::destroy()
     if( s_instance )
     {
         delete s_instance;
-        s_instance = 0;
+        s_instance = nullptr;
     }
 }
 
@@ -84,17 +84,20 @@ PlaylistBrowserNS::UserModel::setData( const QModelIndex &idx, const QVariant &v
     {
         case PlaylistBrowserModel::PlaylistItemColumn:
         {
-            debug() << "setting name of item " << idx.internalId() << " to " << value.toString();
-            Playlists::PlaylistPtr item = m_playlists.value( idx.internalId() );
-            item->setName( value.toString() );
-            break;
+            QString newName = value.toString().trimmed();
+            if( newName.isEmpty() )
+                return false;
+            Playlists::PlaylistPtr playlist = m_playlists.value( idx.internalId() );
+            // we Q_EMIT dataChanged signals later
+            return The::playlistManager()->rename( playlist, newName );
         }
         case PlaylistBrowserModel::LabelColumn:
         {
             debug() << "changing group of item " << idx.internalId() << " to " << value.toString();
             Playlists::PlaylistPtr item = m_playlists.value( idx.internalId() );
             item->setGroups( value.toStringList() );
-            break;
+            // we Q_EMIT dataChanged signals later
+            return true;
         }
         default:
             return false;
@@ -166,39 +169,16 @@ PlaylistBrowserNS::UserModel::dropMimeData ( const QMimeData *data, Qt::DropActi
 {
     Q_UNUSED( column )
 
-    if( action == Qt::IgnoreAction )
+    //let the base class handle the regular actions.
+    if( PlaylistBrowserModel::dropMimeData( data, action, row, column, parent ) )
         return true;
 
-    //drop on track is not possible
-    if( IS_TRACK(parent) )
-            return false;
-
-    if( data->hasFormat( AmarokMimeData::TRACK_MIME ) )
-    {
-        const AmarokMimeData* dragList = dynamic_cast<const AmarokMimeData*>( data );
-        if( !dragList )
-            return false;
-
-        int playlistRow = REMOVE_TRACK_MASK(parent.internalId());
-        Playlists::PlaylistPtr playlist = m_playlists.value( playlistRow );
-        if( playlist )
-        {
-            int insertAt = (row == -1) ? playlist->tracks().count() : row;
-            foreach( Meta::TrackPtr track, dragList->tracks() )
-                playlist->addTrack( track, insertAt++ );
-        }
-        return !playlist.isNull();
-    }
-
     if( data->hasUrls() )
     {
-        bool success = true;
         foreach( const QUrl &url, data->urls() )
-            success = The::playlistManager()->import( url.toString() ) ? success : false;
-        return success;
+            The::playlistManager()->import( url );
     }
 
     return false;
 }
 
-#include "UserPlaylistModel.moc"
