@@ -23,7 +23,7 @@
 #include "SvgHandler.h"
 
 #include <KDateTime>
-#include <KIcon>
+#include <QIcon>
 #include <KLocale>
 
 #include <Plasma/Label>
@@ -74,7 +74,7 @@ UpcomingEventsWidget::UpcomingEventsWidget( const LastFmEventPtr &event,
         {
             m_mapButton = new Plasma::PushButton( this );
             m_mapButton->setMaximumSize( QSizeF( 22, 22 ) );
-            m_mapButton->setIcon( KIcon("edit-find") ); // TODO: a map icon would be nice
+            m_mapButton->setIcon( QIcon::fromTheme("edit-find") ); // TODO: a map icon would be nice
             m_mapButton->setToolTip( i18n( "View map" ) );
             buttonsLayout->addItem( m_mapButton );
         }
@@ -84,7 +84,7 @@ UpcomingEventsWidget::UpcomingEventsWidget( const LastFmEventPtr &event,
     {
         m_urlButton = new Plasma::PushButton( this );
         m_urlButton->setMaximumSize( QSizeF( 22, 22 ) );
-        m_urlButton->setIcon( KIcon("applications-internet") );
+        m_urlButton->setIcon( QIcon::fromTheme("internet-services") );
         m_urlButton->setToolTip( i18n( "Open Last.fm webpage for this event" ) );
         connect( m_urlButton, SIGNAL(clicked()), this, SLOT(openUrl()) );
         buttonsLayout->addItem( m_urlButton );
@@ -92,7 +92,7 @@ UpcomingEventsWidget::UpcomingEventsWidget( const LastFmEventPtr &event,
 
     QSizePolicy::Policy minPol = QSizePolicy::Minimum;
     QGraphicsWidget *supportLabel, *venueLabel, *locationLabel, *dateLabel, *attendLabel, *tagsLabel;
-    supportLabel  = createLabel( i18nc("@label:textbox Supporing acts for an event", "Supporting:"), minPol );
+    supportLabel  = createLabel( i18nc("@label:textbox Supporting acts for an event", "Supporting:"), minPol );
     venueLabel    = createLabel( i18nc("@label:textbox", "Venue:"), minPol );
     locationLabel = createLabel( i18nc("@label:textbox", "Location:"), minPol );
     dateLabel     = createLabel( i18nc("@label:textbox", "Date:"), minPol );
@@ -152,7 +152,7 @@ UpcomingEventsWidget::createLabel( const QString &text, QSizePolicy::Policy hPol
 }
 
 void
-UpcomingEventsWidget::setImage( const KUrl &url )
+UpcomingEventsWidget::setImage( const QUrl &url )
 {
     if( url.isValid() )
     {
@@ -177,7 +177,7 @@ UpcomingEventsWidget::loadImage()
         return;
 
     reply->deleteLater();
-    const KUrl &url = reply->request().url();
+    const QUrl &url = reply->request().url();
     if( m_imageUrl != url )
         return;
 
@@ -379,4 +379,3 @@ UpcomingEventsListWidget::setName( const QString &name )
     m_name = name;
 }
 
-#include "UpcomingEventsWidget.moc"
