@@ -21,7 +21,7 @@
 #include "core/meta/forward_declarations.h"
 
 #include <QObject>
-#include <QWeakPointer>
+#include <QPointer>
 #include <QString>
 
 namespace Collections {
@@ -33,22 +33,22 @@ class SqlQueryMakerInternal : public QObject
 Q_OBJECT
 public:
     explicit SqlQueryMakerInternal( SqlCollection *collection );
-    virtual ~ SqlQueryMakerInternal();
+    ~ SqlQueryMakerInternal() override;
 
     void run();
     void setQuery( const QString &query );
     void setQueryType( QueryMaker::QueryType type );
     void setResultAsDataPtrs( bool value );
 
-signals:
-    void newResultReady( Meta::TrackList );
-    void newResultReady( Meta::ArtistList );
-    void newResultReady( Meta::AlbumList );
-    void newResultReady( Meta::GenreList );
-    void newResultReady( Meta::ComposerList );
-    void newResultReady( Meta::YearList );
-    void newResultReady( QStringList );
-    void newResultReady( Meta::LabelList );
+Q_SIGNALS:
+    void newTracksReady( const Meta::TrackList& );
+    void newArtistsReady( const Meta::ArtistList& );
+    void newAlbumsReady( const Meta::AlbumList& );
+    void newGenresReady( const Meta::GenreList& );
+    void newComposersReady( const Meta::ComposerList& );
+    void newYearsReady( const Meta::YearList& );
+    void newResultReady( const QStringList& );
+    void newLabelsReady( const Meta::LabelList& );
 
 private:
     void handleResult( const QStringList &result );
@@ -61,7 +61,7 @@ private:
     void handleLabels( const QStringList &result );
 
 private:
-    QWeakPointer<SqlCollection> m_collection;
+    QPointer<SqlCollection> m_collection;
     QueryMaker::QueryType m_queryType;
     QString m_query;
 
