@@ -20,15 +20,18 @@
 #include "../PlaydarMeta.h"
 #include "core/support/Debug.h"
 
-#include <qjson/parser.h>
+#include <QJsonArray>
+#include <QJsonDocument>
+#include <QJsonObject>
+#include <QJsonParseError>
+#include <QMap>
+#include <QString>
+#include <QUrl>
+#include <QVariant>
+#include <QVariantMap>
 
-#include <KUrl>
 #include <KIO/Job>
 
-#include <QString>
-#include <QVariant>
-#include <QMap>
-#include <QVariantMap>
 
 namespace Playdar
 {
@@ -50,10 +53,10 @@ namespace Playdar
         if( m_waitForSolution )
         {
             m_receivedFirstResults = true;
-            m_controller.data()->getResultsLongPoll( this );
+            m_controller->getResultsLongPoll( this );
         }
         else
-            m_controller.data()->getResults( this );
+            m_controller->getResults( this );
     }
     
     Query::~Query()
@@ -117,51 +120,55 @@ namespace Playdar
         
         if( resultsJob->error() != 0 ) {
             debug() << "Error getting results from Playdar";
-            emit playdarError( Playdar::Controller::ErrorState( 1 ) );
+            Q_EMIT playdarError( Playdar::Controller::ErrorState( 1 ) );
             return;
         }
         
         debug() << "Processing received JSON data...";
         KIO::StoredTransferJob* storedResultsJob = static_cast<KIO::StoredTransferJob*>( resultsJob );
                 
-        QJson::Parser parser;
-        bool ok;
-        QVariant parsedResultsVariant;
-        parsedResultsVariant = parser.parse( storedResultsJob->data(),&ok );
-        if ( !ok )
+        QJsonParseError err;
+        auto doc = QJsonDocument::fromJson( storedResultsJob->data(), &err );
+
+        if ( err.error != QJsonParseError::NoError )
+            debug() << "Error parsing JSON Data:" << err.errorString();
+
+        if( !doc.isObject() )
         {
-            debug() << "Error parsing JSON Data";
+            debug() << "Parsed Json data is not an object";
+            return;
         }
-        
-        QVariantMap parsedResults = parsedResultsVariant.toMap();
-        if( !parsedResults.contains( "results" ) )
+
+        auto object = doc.object();
+
+        if( !object.contains( "results" ) )
         {
             debug() << "Expecting results in Playdar's response, received none";
-            emit playdarError( Playdar::Controller::ErrorState( 6 ) );
+            Q_EMIT playdarError( Playdar::Controller::ErrorState( 6 ) );
             return;
         }
-        if( !parsedResults.contains( "qid" ) )
+        if( !object.contains( "qid" ) )
         {
             debug() << "Expected qid in Playdar's response, received none";
-            emit playdarError( Playdar::Controller::ErrorState( 4 ) );
+            Q_EMIT playdarError( Playdar::Controller::ErrorState( 4 ) );
             return;
         }
-        if( parsedResults.value( "qid" ) != m_qid )
+        if( object.value( "qid" ) != m_qid )
         {
             debug() << "A query received the wrong results from Playdar...";
-            emit playdarError( Playdar::Controller::ErrorState( 5 ) );
+            Q_EMIT playdarError( Playdar::Controller::ErrorState( 5 ) );
             return;
         }
         
-        m_artist = parsedResults.value( "artist" ).toString();
-        m_album = parsedResults.value( "album" ).toString();
-        m_title = parsedResults.value( "track" ).toString();
+        m_artist = object.value( "artist" ).toString();
+        m_album = object.value( "album" ).toString();
+        m_title = object.value( "track" ).toString();
         
-        foreach( const QVariant &resultVariant, parsedResults.value( "results" ).toList() )
+        for( const auto &resultVariant : object.value( "results" ).toArray() )
         {
-            QVariantMap result = resultVariant.toMap();
+            auto result = resultVariant.toObject();
             Meta::PlaydarTrackPtr aTrack;
-            KUrl resultUrl( m_controller.data()->urlForSid( result.value( "sid" ).toString() ) );
+            QUrl resultUrl( m_controller->urlForSid( result.value( "sid" ).toString() ) );
             
             QString trackSid = result.value( "sid" ).toString();
             QString trackUrl = resultUrl.url();
@@ -190,11 +197,11 @@ namespace Playdar
             {
                 m_solved = true;
                 m_trackList.prepend( aTrack );
-                emit querySolved( aTrack );
+                Q_EMIT querySolved( aTrack );
                 
                 if( m_waitForSolution )
                 {
-                    emit queryDone( this, m_trackList );
+                    Q_EMIT queryDone( this, m_trackList );
                     return;
                 }
             }
@@ -202,18 +209,18 @@ namespace Playdar
             {
                 m_trackList.append( aTrack );
             }
-            emit newTrackAdded( aTrack );
+            Q_EMIT newTrackAdded( aTrack );
         }
         
         if( m_receivedFirstResults || m_solved )
         {
             m_receivedFirstResults = true;
-            emit queryDone( this, m_trackList );
+            Q_EMIT queryDone( this, m_trackList );
         }
         else
         {
             m_receivedFirstResults = true;
-            m_controller.data()->getResultsLongPoll( this );
+            m_controller->getResultsLongPoll( this );
         }
     }
 }
