@@ -39,6 +39,8 @@
 #include <QLabel>
 #include <QMenu>
 
+#include <algorithm>
+
 CollectionSetup* CollectionSetup::s_instance;
 
 
@@ -336,9 +338,9 @@ namespace CollectionFolder {
     QStringList
     Model::directories() const
     {
-        QStringList dirs = m_checked.toList();
+        QStringList dirs = m_checked.values();
 
-        qSort( dirs.begin(), dirs.end() );
+        std::sort( dirs.begin(), dirs.end() );
 
         // we need to remove any children of selected items as
         // they are redundant when recursive mode is chosen
