@@ -67,7 +67,7 @@ TagDialog::TagDialog( const Meta::TrackList &tracks, QWidget *parent )
     , m_perTrack( true )
     , m_currentTrackNum( 0 )
     , m_changed( false )
-    , m_queryMaker( 0 )
+    , m_queryMaker( nullptr )
     , ui( new Ui::TagDialogBase() )
 {
     DEBUG_BLOCK
@@ -86,7 +86,7 @@ TagDialog::TagDialog( Meta::TrackPtr track, QWidget *parent )
     , m_perTrack( true )
     , m_currentTrackNum( 0 )
     , m_changed( false )
-    , m_queryMaker( 0 )
+    , m_queryMaker( nullptr )
     , ui( new Ui::TagDialogBase() )
 {
     DEBUG_BLOCK
@@ -133,6 +133,9 @@ TagDialog::~TagDialog()
     if( m_currentAlbum )
         unsubscribeFrom( m_currentAlbum );
 
+    // kRichTextEdit creates a signal during deletion which causes getTagsFromUi to access deleted objects BUG: 428769
+    ui->kRichTextEdit_lyrics->disconnect();
+
     delete ui;
 }
 
@@ -257,7 +260,7 @@ TagDialog::dataQueryDone()
     // we do this because if we insert items and the contents of the textbox
     // are not in the list, it clears the textbox. which is bad --lfranchi 2.22.09
     QString saveText( ui->kComboBox_artist->lineEdit()->text() );
-    QStringList artists = m_artists.toList();
+    QStringList artists = m_artists.values();
     artists.sort();
     ui->kComboBox_artist->clear();
     ui->kComboBox_artist->insertItems( 0, artists );
@@ -265,7 +268,7 @@ TagDialog::dataQueryDone()
     ui->kComboBox_artist->lineEdit()->setText( saveText );
 
     saveText = ui->kComboBox_album->lineEdit()->text();
-    QStringList albums = m_albums.toList();
+    QStringList albums = m_albums.values();
     albums.sort();
     ui->kComboBox_album->clear();
     ui->kComboBox_album->insertItems( 0, albums );
@@ -273,7 +276,7 @@ TagDialog::dataQueryDone()
     ui->kComboBox_album->lineEdit()->setText( saveText );
 
     saveText = ui->kComboBox_albumArtist->lineEdit()->text();
-    QStringList albumArtists = m_albumArtists.toList();
+    QStringList albumArtists = m_albumArtists.values();
     albumArtists.sort();
     ui->kComboBox_albumArtist->clear();
     ui->kComboBox_albumArtist->insertItems( 0, albumArtists );
@@ -281,7 +284,7 @@ TagDialog::dataQueryDone()
     ui->kComboBox_albumArtist->lineEdit()->setText( saveText );
 
     saveText = ui->kComboBox_composer->lineEdit()->text();
-    QStringList composers = m_composers.toList();
+    QStringList composers = m_composers.values();
     composers.sort();
     ui->kComboBox_composer->clear();
     ui->kComboBox_composer->insertItems( 0, composers );
@@ -289,7 +292,7 @@ TagDialog::dataQueryDone()
     ui->kComboBox_composer->lineEdit()->setText( saveText );
 
     saveText = ui->kComboBox_genre->lineEdit()->text();
-    QStringList genres = m_genres.toList();
+    QStringList genres = m_genres.values();
     genres.sort();
     ui->kComboBox_genre->clear();
     ui->kComboBox_genre->insertItems( 0, genres );
@@ -297,7 +300,7 @@ TagDialog::dataQueryDone()
     ui->kComboBox_genre->lineEdit()->setText( saveText );
 
     saveText = ui->kComboBox_label->lineEdit()->text();
-    QStringList labels = m_allLabels.toList();
+    QStringList labels = m_allLabels.values();
     labels.sort();
     ui->kComboBox_label->clear();
     ui->kComboBox_label->insertItems( 0, labels );
@@ -489,7 +492,7 @@ TagDialog::guessFromFilename() //SLOT
         }
         else
         {
-            debug() << "guessing tags from filename failed" << endl;
+            debug() << "guessing tags from filename failed" << Qt::endl;
         }
     }
 }
@@ -579,8 +582,8 @@ void TagDialog::initUi()
     connect( ui->removeButton,        &QAbstractButton::clicked, this, &TagDialog::removeLabelPressed );
     connect( ui->kComboBox_label,     QOverload<int>::of(&KComboBox::activated), this, &TagDialog::labelModified );
     connect( ui->kComboBox_label,     &QComboBox::editTextChanged, this, &TagDialog::labelModified );
-    connect( ui->kComboBox_label,     QOverload<>::of(&KComboBox::returnPressed), this, &TagDialog::addLabelPressed );
-    connect( ui->kComboBox_label,     QOverload<>::of(&KComboBox::returnPressed), this, &TagDialog::checkChanged );
+    connect( ui->kComboBox_label,     QOverload<const QString&>::of(&KComboBox::returnPressed), this, &TagDialog::addLabelPressed );
+    connect( ui->kComboBox_label,     QOverload<const QString&>::of(&KComboBox::returnPressed), this, &TagDialog::checkChanged );
     connect( ui->labelsList,          &QListView::pressed, this, &TagDialog::labelSelected );
 
     ui->pixmap_cover->setContextMenuPolicy( Qt::CustomContextMenu );
@@ -897,10 +900,12 @@ TagDialog::getTagsFromUi( const QVariantMap &tags ) const
             map.insert( Meta::Field::LYRICS, ui->kRichTextEdit_lyrics->textOrHtml() );
     }
 
-    QSet<QString> uiLabels = m_labelModel->labels().toSet();
-    QSet<QString> oldLabels = tags.value( Meta::Field::LABELS ).toStringList().toSet();
+    QStringList uiLabelsList = m_labelModel->labels();
+    QSet<QString> uiLabels(uiLabelsList.begin(), uiLabelsList.end());
+    QStringList oldLabelsList = tags.value( Meta::Field::LABELS ).toStringList();
+    QSet<QString> oldLabels(oldLabelsList.begin(), oldLabelsList.end());
     if( uiLabels != oldLabels )
-        map.insert( Meta::Field::LABELS, QVariant( uiLabels.toList() ) );
+        map.insert( Meta::Field::LABELS, QVariant( uiLabels.values() ) );
 
     return map;
 }
@@ -1020,11 +1025,15 @@ TagDialog::getTagsFromMultipleTracks() const
         // -- figure out which tags do not match.
 
         // - occur not in every file
-        mismatchingTags |= map.keys().toSet() - tags.keys().toSet();
-        mismatchingTags |= tags.keys().toSet() - map.keys().toSet();
+        QStringList mapkeys=map.keys();
+        QStringList tagskeys=tags.keys();
+        QSet<QString> mapKeysSet(mapkeys.begin(), mapkeys.end());
+        QSet<QString> tagsKeysSet(tagskeys.begin(), tagskeys.end());
+        mismatchingTags |= mapKeysSet - tagsKeysSet;
+        mismatchingTags |= tagsKeysSet - mapKeysSet;
 
         // - not the same in every file
-        foreach( const QString &key, (map.keys().toSet() & tags.keys().toSet()) )
+        foreach( const QString &key, (mapKeysSet & tagsKeysSet) )
         {
             if( map.value( key ) != tags.value( key ) )
                 mismatchingTags.insert( key );
@@ -1158,8 +1167,10 @@ TagDialog::setTagsToTrack()
             if( newTags.contains( Meta::Field::LABELS ) )
             {
                 // determine the differences
-                QSet<QString> oldLabelsSet = oldTags.value( Meta::Field::LABELS ).toStringList().toSet();
-                QSet<QString> newLabelsSet = newTags.value( Meta::Field::LABELS ).toStringList().toSet();
+                QStringList oldTagsList = oldTags.value( Meta::Field::LABELS ).toStringList();
+                QSet<QString> oldLabelsSet(oldTagsList.begin(), oldTagsList.end());
+                QStringList newTagsList = newTags.value( Meta::Field::LABELS ).toStringList();
+                QSet<QString> newLabelsSet(newTagsList.begin(), newTagsList.end());
 
                 QSet<QString> labelsToRemove = oldLabelsSet - newLabelsSet;
                 QSet<QString> labelsToAdd = newLabelsSet - oldLabelsSet;
@@ -1167,11 +1178,12 @@ TagDialog::setTagsToTrack()
                 // apply the differences for each track
                 foreach( const Meta::TrackPtr &track, m_tracks )
                 {
-                    QSet<QString> labelsSet = m_storedTags[track].value( Meta::Field::LABELS ).toStringList().toSet();
+                    QStringList labelsList = m_storedTags[track].value( Meta::Field::LABELS ).toStringList();
+                    QSet<QString> labelsSet(labelsList.begin(), labelsList.end());
                     labelsSet += labelsToAdd;
                     labelsSet -= labelsToRemove;
 
-                    m_storedTags[ track ].insert( Meta::Field::LABELS, QVariant( labelsSet.toList() ) );
+                    m_storedTags[ track ].insert( Meta::Field::LABELS, QVariant( labelsSet.values() ) );
                 }
             }
         }
@@ -1312,11 +1324,14 @@ TagDialog::saveTags()
                     labelMap.insert( label->name(), label );
 
                 // labels to remove
-                for( const auto &label : labelMap.keys().toSet() - labels.toSet() )
+                QStringList labelmapkeys=labelMap.keys();
+                QSet<QString> labelMapKeysSet(labelmapkeys.begin(), labelmapkeys.end());
+                QSet<QString> labelsSet(labels.begin(), labels.end());
+                for( const auto &label : labelMapKeysSet - labelsSet )
                     track->removeLabel( labelMap.value( label ) );
 
                 // labels to add
-                for( const auto &label : labels.toSet() - labelMap.keys().toSet() )
+                for( const auto &label : labelsSet - labelMapKeysSet )
                     track->addLabel( label );
 
                 Meta::TrackEditorPtr ec = track->editor();
