@@ -25,7 +25,7 @@
 #include "core/meta/Statistics.h"
 #include "core/support/Amarok.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 
 TrackOrganizer::TrackOrganizer( const Meta::TrackList &tracks, QObject* parent )
     : QObject( parent )
@@ -67,7 +67,7 @@ QString TrackOrganizer::buildDestination(const QString& format, const Meta::Trac
 
     if ( track->trackNumber() )
     {
-        QString trackNum = QString("%1").arg( track->trackNumber(), 2, 10, QChar('0') );
+        QString trackNum = QStringLiteral("%1").arg( track->trackNumber(), 2, 10, QChar('0') );
         args["track"] = trackNum;
     }
     args["title"] = track->name();
@@ -97,7 +97,7 @@ QString TrackOrganizer::buildDestination(const QString& format, const Meta::Trac
     args["filesize"] = track->filesize();
     args["length"] = track->length() / 1000;
 
-    // Fill up default empty values for StringX formater
+    // Fill up default empty values for StringX formatter
     // TODO make this values changeable by user
     args["default_album"]           = i18n( "Unknown album" );
     args["default_albumartist"]     = i18n( "Unknown artist" );
@@ -113,7 +113,7 @@ QString TrackOrganizer::buildDestination(const QString& format, const Meta::Trac
 
     foreach( const QString &key, args.keys() )
         if( key != "collectionroot" && key != "folder" )
-            args[key] = args[key].replace( '/', '-' );
+            args[key] = args[key].replace( QLatin1Char('/'), '-' );
 
     Amarok::QStringx formatx( format );
     QString result = formatx.namedOptArgs( args );
