@@ -25,13 +25,13 @@
 #include "statusbar/StatusBar.h"
 
 #include <KConfigGroup>
-#include <KDialog>
-#include <KGlobal>
+#include <QDialog>
+
 #include <KIconLoader>
 #include <KIO/DeleteJob>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KStandardGuiItem>
-#include <KUrl>
+#include <QUrl>
 
 
 
@@ -49,11 +49,11 @@ DeleteWidget::DeleteWidget(QWidget *parent)
     ddShouldDelete->setChecked(deleteInstead);
 }
 
-void DeleteWidget::setFiles(const KUrl::List &files)
+void DeleteWidget::setFiles(const QList<QUrl> &files)
 {
     ddFileList->clear();
 //    ddFileList->insertStringList(files);
-    for( KUrl::List::ConstIterator it = files.constBegin(), end = files.constEnd(); it != end; ++it)
+    for( QList<QUrl>::ConstIterator it = files.constBegin(), end = files.constEnd(); it != end; ++it)
     {
         if( (*it).isLocalFile() ) //path is nil for non-local
             ddFileList->insertItem( (*it).path() );
@@ -83,7 +83,7 @@ void DeleteWidget::slotShouldDelete(bool shouldDelete)
 //////////////////////////////////////////////////////////////////////////////
 
 DeleteDialog::DeleteDialog( QWidget *parent, const char *name )
-    : KDialog( parent ),
+    : QDialog( parent ),
     m_trashGuiItem(i18n("&Send to Trash"), "user-trash-full")
 {
 //Swallow, Qt::WStyle_DialogBorder, parent, name,
@@ -105,18 +105,18 @@ DeleteDialog::DeleteDialog( QWidget *parent, const char *name )
     adjustSize();
 
     slotShouldDelete(shouldDelete());
-    connect(m_widget->ddShouldDelete, SIGNAL(toggled(bool)), SLOT(slotShouldDelete(bool)));
+    connect(m_widget->ddShouldDelete, &QCheckBox::toggled, this, &DeleteDialog::slotShouldDelete);
 
 }
 
-bool DeleteDialog::confirmDeleteList(const KUrl::List& condemnedFiles)
+bool DeleteDialog::confirmDeleteList(const QList<QUrl>& condemnedFiles)
 {
     m_widget->setFiles(condemnedFiles);
 
     return exec() == QDialog::Accepted;
 }
 
-void DeleteDialog::setFiles(const KUrl::List &files)
+void DeleteDialog::setFiles(const QList<QUrl> &files)
 {
     m_widget->setFiles(files);
 }
@@ -130,7 +130,7 @@ void DeleteDialog::accept()
     messageGroup.writeEntry("deleteInsteadOfTrash", shouldDelete());
     messageGroup.sync();
 
-    KDialog::accept();
+    QDialog::accept();
 }
 
 void DeleteDialog::slotShouldDelete(bool shouldDelete)
@@ -138,7 +138,7 @@ void DeleteDialog::slotShouldDelete(bool shouldDelete)
     setButtonGuiItem(Ok, shouldDelete ? KStandardGuiItem::del() : m_trashGuiItem);
 }
 
-bool DeleteDialog::showTrashDialog(QWidget* parent, const KUrl::List& files)
+bool DeleteDialog::showTrashDialog(QWidget* parent, const QList<QUrl>& files)
 {
     DeleteDialog dialog(parent);
     bool doDelete = dialog.confirmDeleteList(files);
@@ -148,7 +148,7 @@ bool DeleteDialog::showTrashDialog(QWidget* parent, const KUrl::List& files)
         KIO::Job* job = 0;
         bool shouldDelete = dialog.shouldDelete();
         if ( ( shouldDelete && (job = KIO::del( files )) ) ||
-             ( job = App::instance()->trashFiles( files )   ) )
+             ( job = pApp->trashFiles( files )   ) )
         {
             if(shouldDelete) //amarok::trashFiles already does the progress operation
                 The::statusBar()->newProgressOperation( job, i18n("Deleting files") );
@@ -159,7 +159,6 @@ bool DeleteDialog::showTrashDialog(QWidget* parent, const KUrl::List& files)
 
     return doDelete;
 }
-#include "deletedialog.moc"
 
 // vim: set et ts=4 sw=4:
 
