@@ -23,6 +23,7 @@
 #include <QEventLoop>
 #include <QFileSystemWatcher>
 #include <QMutexLocker>
+#include <QRandomGenerator>
 #include <QStringList>
 #include <QTemporaryFile>
 
@@ -66,7 +67,7 @@ AmarokEmbeddedSqlConnection::connection()
     socket.open();
 
     // Get random port in range 3307 - 65535
-    const int port = ( qrand() % ( 65536 - 3307 ) ) + 3307;
+    const int port = ( QRandomGenerator::global()->generate() % ( 65536 - 3307 ) ) + 3307;
 
     QSqlDatabase::removeDatabase( m_connectionName );
     QSqlDatabase db = QSqlDatabase::addDatabase( "QMYSQL", m_connectionName );
@@ -120,7 +121,7 @@ AmarokEmbeddedSqlConnection::startServer( const int port, const QString &socketP
              &loop,    &QEventLoop::quit, Qt::QueuedConnection );
     connect( &watcher, &QFileSystemWatcher::fileChanged,
              &loop,    &QEventLoop::quit, Qt::QueuedConnection );
-    connect( &m_srv,   QOverload<QProcess::ProcessError>::of( &QProcess::error ),
+    connect( &m_srv,   QOverload<QProcess::ProcessError>::of( &QProcess::errorOccurred ),
              &loop,    &QEventLoop::quit, Qt::QueuedConnection );
 
     // Important: we use modification of pidfile as a cue that the server is ready
