@@ -47,12 +47,10 @@ AMAROK_EXPORT OcsData ocsData;
 
 int main( int argc, char *argv[] )
 {
-    App app(argc, argv);
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
+    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 
-#ifdef WITH_QT_WEBENGINE
-    QtWebEngine::initialize();
-#endif
+    App app(argc, argv);
 
     app.setApplicationDisplayName(i18n("Amarok"));
 
@@ -100,7 +98,7 @@ int main( int argc, char *argv[] )
                           i18n( "The audio player by KDE" ),
                           KAboutLicense::GPL,
                           i18n( "(C) 2002-2003, Mark Kretschmann\n(C) 2003-2013, The Amarok Development Squad" ),
-                          ki18n( "IRC:\nirc.freenode.net - #amarok, #amarok.de, #amarok.es, #amarok.fr\n\nFeedback:\namarok@kde.org\n\n(Build Date: %1)" ).subs( __DATE__ ).toString(),
+                          ki18n( "IRC:\nirc.libera.chat - #amarok, #amarok-de, #amarok-es, #amarok-fr\n\nFeedback:\namarok@kde.org\n\n(Build Date: %1)" ).subs( __DATE__ ).toString(),
                           ( "http://amarok.kde.org" ) );
 
     //------------ About data ----------------------
