@@ -46,7 +46,7 @@ namespace Playlists {
 PlaylistFileProvider::PlaylistFileProvider()
  : UserPlaylistProvider()
  , m_playlistsLoaded( false )
- , m_saveLaterTimer( 0 )
+ , m_saveLaterTimer( nullptr )
 {
     //playlists are lazy loaded but we can count how many we'll load already
     QStringList keys = loadedPlaylistsConfig().keyList();
@@ -139,14 +139,14 @@ PlaylistFileProvider::save( const Meta::TrackList &tracks, const QString &name )
     filename.replace( QLatin1Char('/'), QLatin1Char('-') );
     filename.replace( QLatin1Char('\\'), QLatin1Char('-') );
 
-    Playlists::PlaylistFormat format = Playlists::getFormat( QUrl::fromUserInput(filename) );
+    Playlists::PlaylistFormat format = Playlists::getFormat( QUrl::fromUserInput( filename, QString(), QUrl::AssumeLocalFile ) );
     if( format == Playlists::Unknown ) // maybe the name just had a dot in it. We just add .xspf
     {
         format = Playlists::XSPF;
         filename.append( QLatin1String( ".xspf" ) );
     }
 
-    QUrl path( Amarok::saveLocation( QStringLiteral("playlists") ) );
+    QUrl path = QUrl::fromLocalFile( Amarok::saveLocation( QStringLiteral("playlists") ) );
     path = path.adjusted(QUrl::StripTrailingSlash);
     path.setPath(path.path() + QLatin1Char('/') + ( Amarok::vfatPath( filename ) ));
     if( QFileInfo( path.toLocalFile() ).exists() )
@@ -155,7 +155,7 @@ PlaylistFileProvider::save( const Meta::TrackList &tracks, const QString &name )
         return Playlists::PlaylistPtr();
     }
 
-    Playlists::PlaylistFile *playlistFile = 0;
+    Playlists::PlaylistFile *playlistFile = nullptr;
     switch( format )
     {
         case Playlists::ASX:
@@ -293,7 +293,7 @@ PlaylistFileProvider::loadPlaylists()
         }
 
         if( !groups.isEmpty() && playlist->isWritable() )
-            playlist->setGroups( groups.split( QLatin1Char(','),  QString::SkipEmptyParts ) );
+            playlist->setGroups( groups.split( QLatin1Char(','),  Qt::SkipEmptyParts ) );
 
         m_playlists << playlist;
         Q_EMIT playlistAdded( PlaylistPtr( playlist.data() ) );
