@@ -15,8 +15,9 @@
  ****************************************************************************************/
 
 #include "ServiceCollectionLocation.h"
-#include "Debug.h"
-using namespace Meta;
+#include "core/support/Debug.h"
+
+using namespace Collections;
 
 ServiceCollectionLocation::ServiceCollectionLocation()
     : CollectionLocation()
@@ -24,9 +25,9 @@ ServiceCollectionLocation::ServiceCollectionLocation()
     , m_overwriteFiles( false )
 {}
 
-ServiceCollectionLocation::ServiceCollectionLocation( const ServiceCollection* parentCollection )
-    : CollectionLocation()
-    , m_collection( const_cast<ServiceCollection*>( parentCollection ) )
+ServiceCollectionLocation::ServiceCollectionLocation( ServiceCollection *parentCollection )
+    : CollectionLocation( parentCollection )
+    , m_collection( parentCollection )
     , m_removeSources( false )
     , m_overwriteFiles( false )
 {}
@@ -53,10 +54,10 @@ bool ServiceCollectionLocation::isOrganizable() const
 void
 ServiceCollectionLocation::getKIOCopyableUrls( const Meta::TrackList &tracks )
 {
-    QMap<Meta::TrackPtr, KUrl> urls;
-    foreach( Meta::TrackPtr track, tracks )
+    QMap<Meta::TrackPtr, QUrl> urls;
+    foreach( const Meta::TrackPtr &track, tracks )
     {
-        ServiceTrack *servtrack = static_cast<ServiceTrack *>( track.data() );
+        Meta::ServiceTrack *servtrack = static_cast<Meta::ServiceTrack *>( track.data() );
         if( servtrack->isPlayable() )
             urls.insert( track, servtrack->downloadableUrl() );
     }
