@@ -114,8 +114,8 @@ SynchronizeTracksJob::run(ThreadWeaver::JobPointer self, ThreadWeaver::Thread *t
         // wait 3 seconds so that we have chance to catch slotTrackScrobbled()..
         QObject::thread()->msleep( 3000 );
     if( controller )
-        disconnect( controller, &StatSyncing::Controller::trackScrobbled, this, 0 );
-    disconnect( controller, &StatSyncing::Controller::scrobbleFailed, this, 0 );
+        disconnect( controller, &StatSyncing::Controller::trackScrobbled, this, nullptr );
+    disconnect( controller, &StatSyncing::Controller::scrobbleFailed, this, nullptr );
 
     Q_EMIT endProgressOperation( this );
 }
