@@ -20,12 +20,13 @@
 
 #include "core/support/Debug.h"
 
+#include <QVBoxLayout>
 
-PopupWidget::PopupWidget( QWidget *anchor, const QString &name )
-        : KVBox( The::mainWindow() )
+
+PopupWidget::PopupWidget( const QString &name )
+    : BoxWidget( true )
 {
     Q_UNUSED( name );
-    Q_UNUSED( anchor );
 
     setBackgroundRole( QPalette::Window );
     setAutoFillBackground( true );
@@ -36,10 +37,7 @@ PopupWidget::PopupWidget( QWidget *anchor, const QString &name )
     setMinimumHeight( 26 );
 
     setContentsMargins( 4, 4, 4, 4 );
-    setSpacing( 0 );
     setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
-
-    reposition();
 }
 
 PopupWidget::~PopupWidget()
@@ -51,6 +49,9 @@ void PopupWidget::reposition()
 {
     adjustSize();
 
+    if( !The::mainWindow() )
+        return;
+
     //HACK: put longmessage popup in the bottom right of the window.
     QPoint p;
     p.setX( The::mainWindow()->width() - width() );
