@@ -24,6 +24,7 @@
 #include <QMouseEvent>
 #include <QPaintEvent>
 #include <QWidget>
+#include <QPoint>
 
 class QSize;
 class QSizePolicy;
@@ -33,32 +34,49 @@ class BookmarkTriangle : public QWidget
 {
     Q_OBJECT
 public:
-    BookmarkTriangle ( QWidget *parent, int milliseconds, QString name , bool showPopup = false);
-    ~BookmarkTriangle();
-    virtual QSize sizeHint() const;
+    BookmarkTriangle( QWidget *parent, int milliseconds, const QString &name, int sliderwidth,
+                      bool showPopup = false );
+    ~BookmarkTriangle() override;
+    QSize sizeHint() const override;
     virtual QSizePolicy sizePolicy() const;
-    virtual QSize minimumSizeHint() const;
+    QSize minimumSizeHint() const override;
 
-    virtual void showEvent ( QShowEvent * event );
-    virtual void mousePressEvent ( QMouseEvent * event );
-    virtual void mouseReleaseEvent  (QMouseEvent *);
-    virtual void enterEvent ( QEvent * event );
-    virtual void leaveEvent ( QEvent * event );
-    virtual void paintEvent ( QPaintEvent* );
+    void showEvent ( QShowEvent * event ) override;
+    void mousePressEvent ( QMouseEvent * event ) override;
+    void mouseMoveEvent ( QMouseEvent * event ) override;
+    void mouseReleaseEvent  (QMouseEvent *) override;
+    void enterEvent ( QEvent * event ) override;
+    void leaveEvent ( QEvent * event ) override;
+    void paintEvent ( QPaintEvent* ) override;
 
     virtual void hidePopup();
+
+    /**
+     * Updates the position of the bookmark named @p name to @p newMilliseconds.
+     *
+     * The name should be a valid existing bookmark name and should include the trailing
+     * "- m:ss"
+     * @param name the name
+     * @param newMilliseconds the new position in milliseconds
+     */
+    virtual void moveBookmark( qint64 newMilliseconds, const QString &name );
+
     virtual void deleteBookmark();
     virtual int getTimeValue();
 
-signals:
+Q_SIGNALS:
     void clicked ( int );
     void focused ( int );
 
 private:
     void initPopup();
-    int m_mseconds;
-    QString m_name;
-    bool m_showPopup;
-    BookmarkPopup* m_tooltip;
+
+    int m_mseconds; /// position of the bookmark on the slider in terms of milliseconds
+    QString m_name; /// name of the bookmark
+    int m_sliderwidth; /// width of the slider on which the bookmark will appear
+    bool m_showPopup; /// used to determine whether to show the Pop-up on focusing the bookmark
+    BookmarkPopup* m_tooltip; /// the tooltip that appears on focusing the bookmark
+    QPoint m_offset; /// used while moving the bookmark, holds the position of the bookmark before moving
+    int m_pos; /// used while moving the bookmark, holds the x co-ordinate of the bookmark after moving
 };
 #endif // BOOKMARKTRIANGLE_H
