@@ -24,7 +24,6 @@
 #include <QString>
 #include <QPixmap>
 
-class QMouseEvent;
 class QPixmap;
 
 class PixmapViewer : public QWidget
@@ -33,20 +32,20 @@ class PixmapViewer : public QWidget
     Q_PROPERTY( qreal zoomFactor READ zoomFactor WRITE setZoomFactor NOTIFY zoomFactorChanged )
 
 public:
-    PixmapViewer( QWidget *parent, const QPixmap &pixmap, int screenNumber );
-    virtual ~PixmapViewer();
+    explicit PixmapViewer( QWidget *parent, const QPixmap &pixmap, int screenNumber );
+    ~PixmapViewer() override;
 
     qreal zoomFactor() const;
 
-public slots:
+public Q_SLOTS:
     void setZoomFactor( qreal f );
 
-signals:
+Q_SIGNALS:
     void zoomFactorChanged( qreal );
 
 protected:
-    void paintEvent( QPaintEvent *event );
-    void wheelEvent( QWheelEvent *event );
+    void paintEvent( QPaintEvent *event ) override;
+    void wheelEvent( QWheelEvent *event ) override;
 
 private:
     const QPixmap m_pixmap;
