@@ -18,36 +18,36 @@
 
 #include "TrackSelectWidget.h"
 
+#include "amarokconfig.h"
 #include "browsers/CollectionTreeItem.h"
 #include "browsers/CollectionTreeItemModel.h"
 #include "browsers/CollectionTreeView.h"
-#include "browsers/collectionbrowser/CollectionTreeItemDelegate.h"
+#include "core/meta/Meta.h"
+#include "core/support/Amarok.h"
 #include "core/support/Debug.h"
+#include "widgets/PrettyTreeDelegate.h"
 
-#include <amarokconfig.h>
-
-#include <KLocale>
+#include <KLocalizedString>
 #include <KSqueezedTextLabel>
-#include <KVBox>
 
 #include <QLabel>
+#include <QVBoxLayout>
 
 TrackSelectWidget::TrackSelectWidget( QWidget* parent )
-    : KVBox( parent )
+    : BoxWidget( true, parent )
 {
     DEBUG_BLOCK
+
     m_label = new KSqueezedTextLabel( this );
     m_label->hide(); // TODO: decide whether the label should be shown or not
     m_label->setTextElideMode( Qt::ElideRight );
     setData( Meta::DataPtr() );
 
     m_view = new CollectionTreeView( this );
-    m_view->setAlternatingRowColors( true );
     m_view->setRootIsDecorated( false );
     m_view->setFrameShape( QFrame::NoFrame );
 
-    CollectionTreeItemDelegate* delegate = new CollectionTreeItemDelegate( m_view );
-    m_view->setItemDelegate( delegate );
+    m_view->setItemDelegate( new PrettyTreeDelegate( m_view ) );
 
     QList<int> levelNumbers = Amarok::config( "Collection Browser" ).readEntry( "TreeCategory", QList<int>() );
     QList<CategoryId::CatMenuId> levels;
@@ -56,10 +56,11 @@ TrackSelectWidget::TrackSelectWidget( QWidget* parent )
     if ( levels.isEmpty() )
         levels << CategoryId::Artist << CategoryId::Album;
     m_model = new CollectionTreeItemModel( levels );
+    m_model->setParent( this );
     m_view->setModel( m_model );
 
-    connect( m_view, SIGNAL( itemSelected( CollectionTreeItem* ) ),
-             this, SLOT( recvNewSelection( CollectionTreeItem* ) ) );
+    connect( m_view, &CollectionTreeView::itemSelected,
+             this, &TrackSelectWidget::recvNewSelection );
 }
 
 TrackSelectWidget::~TrackSelectWidget() {}
@@ -78,7 +79,7 @@ TrackSelectWidget::recvNewSelection( CollectionTreeItem* item )
         if ( data != Meta::DataPtr() ) {
             setData( data );
             debug() << "new selection" << data->prettyName();
-            emit selectionChanged( data );
+            Q_EMIT selectionChanged( data );
         }
     }
 }
@@ -87,13 +88,13 @@ const QString TrackSelectWidget::dataToLabel( const Meta::DataPtr& data ) const
 {
     if ( data != Meta::DataPtr() ) {
         if ( Meta::TrackPtr track = Meta::TrackPtr::dynamicCast( data ) ) {
-            return QString( i18n("Track: %1", track->prettyName() ) );
+            return i18n("Track: %1", track->prettyName() );
         } else if ( Meta::AlbumPtr album = Meta::AlbumPtr::dynamicCast( data ) ) {
-            return QString( i18n("Album: %1", album->prettyName() ) );
+            return i18n("Album: %1", album->prettyName() );
         } else if ( Meta::ArtistPtr artist = Meta::ArtistPtr::dynamicCast( data ) ) {
-            return QString( i18n("Artist: %1", artist->prettyName() ) );
+            return i18n("Artist: %1", artist->prettyName() );
         }
         // TODO: can things other than tracks, artists, and albums end up here?
     }
-    return QString( i18n("empty") );
+    return i18n("empty");
 }
