@@ -27,6 +27,8 @@
 #include "core/capabilities/BookmarkThisCapability.h"
 #include "covermanager/CoverFetcher.h"
 
+#include <KLocalizedString>
+
 #include <QFile>
 #include <QImage>
 
@@ -34,10 +36,11 @@ QTEST_MAIN( TestSqlAlbum )
 
 TestSqlAlbum::TestSqlAlbum()
     : QObject()
-    , m_collection( 0 )
-    , m_storage( 0 )
-    , m_tmpDir( 0 )
+    , m_collection( nullptr )
+    , m_storage( nullptr )
+    , m_tmpDir( nullptr )
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
 }
 
 TestSqlAlbum::~TestSqlAlbum()
