@@ -36,9 +36,9 @@ QTEST_GUILESS_MAIN( TestSqlTrack )
 
 TestSqlTrack::TestSqlTrack()
     : QObject()
-    , m_collection( 0 )
-    , m_storage( 0 )
-    , m_tmpDir( 0 )
+    , m_collection( nullptr )
+    , m_storage( nullptr )
+    , m_tmpDir( nullptr )
 {
 }
 
