@@ -33,9 +33,9 @@ TestFastForwardImporter::getProvider()
     QVariantMap cfg = FastForwardConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbDriver", "QSQLITE" );
     cfg.insert( "dbPath", QCoreApplication::applicationDirPath() +
-                          "/importers_files/collection.db" );
+                          "/../tests/importers_files/collection.db" );
 
-    return ProviderPtr( new FastForwardProvider( cfg, 0 ) );
+    return ProviderPtr( new FastForwardProvider( cfg, nullptr ) );
 }
 
 ProviderPtr
@@ -46,13 +46,13 @@ TestFastForwardImporter::getWritableProvider()
 
     const QString dst = base.filePath( "importers_tmp/collection.db" );
     QFile( dst ).remove();
-    QFile( base.filePath( "importers_files/collection.db" ) ).copy( dst );
+    QFile( base.filePath( "../tests/importers_files/collection.db" ) ).copy( dst );
 
     QVariantMap cfg = FastForwardConfigWidget( QVariantMap() ).config();
     cfg.insert( "dbDriver", "QSQLITE" );
     cfg.insert( "dbPath", dst );
 
-    return ProviderPtr( new FastForwardProvider( cfg, 0 ) );
+    return ProviderPtr( new FastForwardProvider( cfg, nullptr ) );
 }
 
 qint64
@@ -65,6 +65,7 @@ TestFastForwardImporter::reliableStatistics() const
 void
 TestFastForwardImporter::init()
 {
+    KLocalizedString::setApplicationDomain("amarok-test");
     m_cfg = FastForwardConfigWidget( QVariantMap() ).config();
 }
 
@@ -158,7 +159,7 @@ TestFastForwardImporter::providerShouldHandleNonexistentDbFile()
 {
     m_cfg.insert( "dbPath", "/Im/sure/this/wont/exist" );
 
-    FastForwardProvider provider( m_cfg, 0 );
+    FastForwardProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -167,7 +168,7 @@ TestFastForwardImporter::providerShouldHandleInvalidDbFile()
 {
     m_cfg.insert( "dbPath", QApplication::applicationFilePath() );
 
-    FastForwardProvider provider( m_cfg, 0 );
+    FastForwardProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -177,7 +178,7 @@ TestFastForwardImporter::providerShouldHandleExternalConnectionError()
     m_cfg.insert( "dbDriver", "QMYSQL" );
     m_cfg.insert( "dbHost", "I hope this isn't a valid hostname" );
 
-    FastForwardProvider provider( m_cfg, 0 );
+    FastForwardProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
@@ -188,7 +189,7 @@ TestFastForwardImporter::providerShouldHandleErroneousConfigValues()
     m_cfg.insert( "dbName", QColor( Qt::red ) );
     m_cfg.insert( "dbPort", "nonsensePort" );
 
-    FastForwardProvider provider( m_cfg, 0 );
+    FastForwardProvider provider( m_cfg, nullptr );
     QVERIFY( provider.artists().isEmpty() );
 }
 
