@@ -25,16 +25,12 @@
 #include "mocks/MockAlbum.h"
 #include "mocks/MockArtist.h"
 
-#include <KCmdLineArgs>
-#include <KGlobal>
-
 #include <QList>
-
-#include <qtest_kde.h>
+#include <QSignalSpy>
 
 #include <gmock/gmock.h>
 
-QTEST_KDEMAIN_CORE( TestUnionJob )
+QTEST_GUILESS_MAIN( TestUnionJob )
 
 using ::testing::Return;
 using ::testing::AnyNumber;
@@ -48,8 +44,8 @@ class MyCollectionLocation : public CollectionLocation
 public:
     Collections::CollectionTestImpl *coll;
 
-    QString prettyLocation() const { return "foo"; }
-    bool isWritable() const { return true; }
+    QString prettyLocation() const override { return "foo"; }
+    bool isWritable() const override { return true; }
     bool remove( const Meta::TrackPtr &track )
     {
         coll->mc->acquireWriteLock();
@@ -60,7 +56,7 @@ public:
         coll->mc->releaseLock();
         return true;
     }
-    void copyUrlsToCollection(const QMap<Meta::TrackPtr, KUrl> &sources, const Transcoding::Configuration& conf)
+    void copyUrlsToCollection(const QMap<Meta::TrackPtr, QUrl> &sources, const Transcoding::Configuration& conf) override
     {
         Q_UNUSED( conf )
         trackCopyCount << sources.count();
@@ -76,7 +72,7 @@ class MyCollectionTestImpl : public CollectionTestImpl
 public:
     MyCollectionTestImpl( const QString &id ) : CollectionTestImpl( id ) {}
 
-    CollectionLocation* location()
+    CollectionLocation* location() override
     {
         MyCollectionLocation *r = new MyCollectionLocation();
         r->coll = this;
@@ -93,7 +89,7 @@ void addMockTrack( Collections::CollectionTestImpl *coll, const QString &trackNa
     Meta::TrackPtr trackPtr( track );
     EXPECT_CALL( *track, name() ).Times( AnyNumber() ).WillRepeatedly( Return( trackName ) );
     EXPECT_CALL( *track, uidUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( trackName + '_' + artistName + '_' + albumName ) );
-    EXPECT_CALL( *track, playableUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( KUrl( '/' + track->uidUrl() ) ) );
+    EXPECT_CALL( *track, playableUrl() ).Times( AnyNumber() ).WillRepeatedly( Return( QUrl( '/' + track->uidUrl() ) ) );
     coll->mc->addTrack( trackPtr );
 
     Meta::AlbumPtr albumPtr = coll->mc->albumMap().value( albumName, QString() /* no album artist */ );
@@ -152,8 +148,10 @@ void addMockTrack( Collections::CollectionTestImpl *coll, const QString &trackNa
 
 TestUnionJob::TestUnionJob() : QObject()
 {
-    KCmdLineArgs::init( KGlobal::activeComponent().aboutData() );
-    ::testing::InitGoogleMock( &KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
+    int argc = 1;
+    char **argv = (char **) malloc(sizeof(char *));
+    argv[0] = strdup( QCoreApplication::applicationName().toLocal8Bit().data() );
+    ::testing::InitGoogleMock( &argc, argv );
     qRegisterMetaType<Meta::TrackList>();
     qRegisterMetaType<Meta::AlbumList>();
     qRegisterMetaType<Meta::ArtistList>();
@@ -177,8 +175,9 @@ TestUnionJob::testEmptyA()
     QVERIFY( trackCopyCount.isEmpty() );
 
     UnionJob *job = new UnionJob( collA, collB );
+    QSignalSpy spy( job, &UnionJob::destroyed );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     QCOMPARE( trackCopyCount.size(), 1 );
     QVERIFY( trackCopyCount.contains( 1 ) );
@@ -201,8 +200,9 @@ TestUnionJob::testEmptyB()
     QVERIFY( trackCopyCount.isEmpty() );
 
     UnionJob *job = new UnionJob( collA, collB );
+    QSignalSpy spy( job, &UnionJob::destroyed );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     QCOMPARE( trackCopyCount.size(), 1 );
     QVERIFY( trackCopyCount.contains( 1 ) );
@@ -226,8 +226,9 @@ TestUnionJob::testAddTrackToBoth()
     QVERIFY( trackCopyCount.isEmpty() );
 
     UnionJob *job = new UnionJob( collA, collB );
+    QSignalSpy spy( job, &UnionJob::destroyed );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     QCOMPARE( trackCopyCount.size(), 2 );
     QCOMPARE( trackCopyCount.at( 0 ), 1 );
@@ -253,8 +254,9 @@ TestUnionJob::testTrackAlreadyInBoth()
     QVERIFY( trackCopyCount.isEmpty() );
 
     UnionJob *job = new UnionJob( collA, collB );
+    QSignalSpy spy( job, &UnionJob::destroyed );
     job->synchronize();
-    QTest::kWaitForSignal( job, SIGNAL(destroyed()), 1000 );
+    spy.wait( 1000 );
 
     QCOMPARE( trackCopyCount.size(), 1 );
     QVERIFY( trackCopyCount.contains( 1 ) );
